@@ -9,7 +9,8 @@ Note:
 REGISTRY_NAME = 'ctypesarrays'
 import ctypes, _ctypes
 
-from OpenGL import constants, constant, error, ERROR_ON_COPY
+from OpenGL import constants, constant, error
+from OpenGL._configflags import ERROR_ON_COPY
 from OpenGL.arrays import formathandler
 HANDLED_TYPES = (list,tuple)
 import operator
@@ -177,4 +178,4 @@ GL_TYPE_TO_ARRAY_MAPPING = {
     constants.GL_CHAR: constants.GLchar,
     constants.GL_BYTE: constants.GLbyte,
     constants.GL_UNSIGNED_BYTE: constants.GLubyte,
-}
\ No newline at end of file
+}
